@@ -22,7 +22,7 @@ RDF library like :mod:`rdflib`.
 This library also provide ways to discover
 FAIR signposting in HTML ``<link>`` annotations and in
 `Link set`_ documents.  Future versions may provide ways to 
-discover/merge these concurently.
+discover/merge these concurrently.
 
 .. _signposting: https://signposting.org/conventions/
 .. _FAIR: https://signposting.org/FAIR/
@@ -31,7 +31,7 @@ discover/merge these concurently.
 .. _Link set: <https://signposting.org/FAIR/#linksetrec>
 """
 
-__version__ = '0.8.2'
+__version__ = '0.8.3'
 
 from typing import List
 import warnings
